@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 1323 2008-12-06 11:04:36Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 1371 2008-12-19 04:31:27Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -235,7 +235,7 @@ class BaseWidgetContainer extends Core
 		return htmlentities($src, ENT_COMPAT, M3_HTML_CHARSET);
 	}
 	/**
-	 * URLをに変換
+	 * URLをエンティティ文字に変換
 	 */
 	function convertUrlToHtmlEntity($src)
 	{
@@ -790,6 +790,24 @@ class BaseWidgetContainer extends Core
 		// 改行コードをbrタグに変換
 		return HtmlEdit::convLineBreakToBr($src);
 	}
+	/**
+	 * Magic3マクロを変換してHTMLを作成
+	 *
+	 * @param string $src			変換するデータ
+	 * @return string				変換後データ
+	 */
+	function convertM3ToHtml($src)
+	{
+		// アプリケーションルートを変換
+		$dest = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $src);
+		
+		// 登録したキーワードを変換
+		$this->gTextConv->convByKeyValue($dest, $dest, true/*改行コーをbrタグに変換*/);
+		
+		// 残っているMagic3タグ削除
+		$dest = $this->gTextConv->deleteM3Tag($dest);
+		return $dest;
+	}
 	/**
 	 * 値のデータをCSV用のエスケープデータに変換
 	 *
