@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: pageManager.php 1334 2008-12-11 02:54:06Z fishbone $
+ * @version    SVN: $Id: pageManager.php 1356 2008-12-15 07:48:42Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -86,23 +86,26 @@ class PageManager extends Core
 	const LIB_JQUERY_CYCLE		= 'jquery.cycle';
 	const LIB_JQUERY_CODEPRESS	= 'jquery.codepress';
 	const LIB_JQUERY_CLUETIP	= 'jquery.cluetip';
+	const LIB_JQUERY_SIMPLETREE	= 'jquery.simpletree';
 	const LIB_JQUERY_UI_PLUS	= 'jquery-ui-plus';
 	const LIB_FCKEDITOR			= 'fckeditor';
 	const LIB_MD5				= 'md5';
 	
 	// Javascriptライブラリ用のファイル
-	const JQUERY_EASING_FILENAME	= 'jquery/jquery.easing.1.3.js';
+	const JQUERY_EASING_FILENAME		= 'jquery/jquery.easing.1.3.js';
 	//const JQUERY_JCAROUSEL_FILENAME	= 'jquery/jquery.jcarousel.pack.js';
-	const JQUERY_JCAROUSEL_FILENAME	= 'jquery/jquery.jcarousel.0.2.3.pack_fixed.js';
-	const JQUERY_JCAROUSEL_CSS		= 'jquery/jquery.jcarousel.css';
+	const JQUERY_JCAROUSEL_FILENAME		= 'jquery/jquery.jcarousel.0.2.3.pack_fixed.js';
+	const JQUERY_JCAROUSEL_CSS			= 'jquery/jquery.jcarousel.css';
 	const JQUERY_CONTEXTMENU_FILENAME	= 'jquery/jquery.contextmenu.r2.packed.js';
-	const JQUERY_THICKBOX_FILENAME	= 'jquery/thickbox-compressed.js';
-	const JQUERY_THICKBOX_CSS		= 'jquery/thickbox.css';
-	const JQUERY_JSHOTKEYS_FILENAME	= 'jquery/jquery.hotkeys.js';
-	const JQUERY_CYCLE_FILENAME		= 'jquery/jquery.cycle.all.pack.js';
+	const JQUERY_THICKBOX_FILENAME		= 'jquery/thickbox-compressed.js';
+	const JQUERY_THICKBOX_CSS			= 'jquery/thickbox.css';
+	const JQUERY_JSHOTKEYS_FILENAME		= 'jquery/jquery.hotkeys.js';
+	const JQUERY_CYCLE_FILENAME			= 'jquery/jquery.cycle.all.pack.js';
 	const JQUERY_CODEPRESS_FILENAME		= 'jquery/jquery.Codepress.js';
-	const JQUERY_CLUETIP_FILENAME	= 'jquery/jquery.cluetip.js';
-	const JQUERY_CLUETIP_CSS		= 'jquery/jquery.cluetip.css';
+	const JQUERY_CLUETIP_FILENAME		= 'jquery/jquery.cluetip.js';
+	const JQUERY_CLUETIP_CSS			= 'jquery/jquery.cluetip.css';
+	const JQUERY_SIMPLETREE_FILENAME	= 'jquery/jquery.simple.tree.js';
+	const JQUERY_SIMPLETREE_CSS			= 'jquery/simple.tree.css';
 	
 	// ファイル名
 	const JQUERY_FILENAME			= 'jquery-1.2.6.pack.js';						// JQuery
@@ -167,7 +170,9 @@ class PageManager extends Core
 								self::LIB_JQUERY_CYCLE		=>	array(	'script' => array(self::JQUERY_CYCLE_FILENAME)),		// jquery.cycle用のファイル
 								self::LIB_JQUERY_CODEPRESS	=>	array(	'script' => array(self::JQUERY_CODEPRESS_FILENAME)),	// jquery.codepress用のファイル
 								self::LIB_JQUERY_CLUETIP	=>	array(	'script' => array(self::JQUERY_CLUETIP_FILENAME),// jquery.cluetip用のファイル
-																		'css'	=> array(self::JQUERY_CLUETIP_CSS)));
+																		'css'	=> array(self::JQUERY_CLUETIP_CSS)),
+								self::LIB_JQUERY_SIMPLETREE	=>	array(	'script' => array(self::JQUERY_SIMPLETREE_FILENAME),// jquery.simpletree用のファイル
+																		'css'	=> array(self::JQUERY_SIMPLETREE_CSS)));
 
 		// 遅延ウィジェットリスト									
 		$this->lateLaunchWidgetList = array();
@@ -1316,7 +1321,6 @@ class PageManager extends Core
 	 */
 	function getMobileHeader()
 	{
-		global $gEnvManager;
 		global $gRequestManager;
 		
 		// 実行コマンドを取得
@@ -1327,6 +1331,10 @@ class PageManager extends Core
 		
 		// キャッシュを保存させない
 		echo '<meta http-equiv="Cache-Control" content="no-cache" />' . M3_NL;
+		
+		// ##### タグ変換用のタグを埋め込む #####
+		// ウィジェット単体実行のときはタグを埋め込まない
+		if (!$this->showWidget) echo self::HEAD_TAG_DESC;			// HTMLヘッダの埋め込みデータ
 	}
 	/**
 	 * 各部品のHTML出力
