@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2008 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 1325 2008-12-07 05:43:54Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 1372 2008-12-19 05:06:38Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -22,7 +22,7 @@
 INSERT INTO _system_config 
 (sc_id,                          sc_value,                  sc_name) VALUES
 ('system_name',                 'Magic3',                   'システム名称'),
-('db_version',                  '2008120601',               'DBバージョン'),
+('db_version',                  '2008120801',               'DBバージョン'),
 ('server_id',                   '',                         'サーバ識別用ID'),
 ('default_lang',                'ja',                       'デフォルト言語'),
 ('multi_language',               '0',                       '多言語対応'),
@@ -75,9 +75,10 @@ INSERT INTO _nav_item
 (300,   0,            2,        'admin_menu', '_config',         0,               '',       'システム管理',         '',                     ''),
 (301,   300,          0,        'admin_menu', 'configsite',      0,               '',       '基本情報',             '基本情報',             'サイト運営者の設定を行います。メールアドレスは必須項目です。'),
 (302,   300,          1,        'admin_menu', 'configsys',       0,               '',       'システム情報',         'システム情報',         'システム全体の設定、運用状況を管理します。'),
-(303,   300,          2,        'admin_menu', 'master',          0,               '',       'システムマスター管理', 'システムマスター管理', 'システムに関するマスターテーブルの管理を行います。'),
-(304,   300,          3,        'admin_menu', 'initsystem',      0,               '',       'DBメンテナンス',       'DBメンテナンス',       'データの初期化などDBのメンテナンスを行います。'),
-(305,   300,          4,        'admin_menu', 'editmenu',        0,               '',       '管理メニュー編集',     '管理メニュー編集',     '管理機能のメインメニューを編集します。'),
+(303,   300,          2,        'admin_menu', 'resbrowse',       0,               '',       'リソースブラウズ',     'リソースブラウズ',     'リソースファイルを管理します。'),
+(304,   300,          3,        'admin_menu', 'master',          0,               '',       'システムマスター管理', 'システムマスター管理', 'システムに関するマスターテーブルの管理を行います。'),
+(305,   300,          4,        'admin_menu', 'initsystem',      0,               '',       'DBメンテナンス',       'DBメンテナンス',       'データの初期化などDBのメンテナンスを行います。'),
+(306,   300,          5,        'admin_menu', 'editmenu',        0,               '',       '管理メニュー編集',     '管理メニュー編集',     '管理機能のメインメニューを編集します。'),
 (399,   0,            3,        'admin_menu', '_399',            1,               '',       '改行',                 '',                     ''),
 (1100,  0,            11,       'admin_menu', '_others',         0,               '',       'その他',               '',                     ''),
 (1101,  1100,         0,        'admin_menu', 'logout',          0,               '',       'ログアウト',           'ログアウト',           '管理機能からログアウトします。');
@@ -87,7 +88,7 @@ INSERT INTO _widgets
 (wd_id,         wd_name, wd_type, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_add_script_lib, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('admin_menu',  '管理用メニュー',  'ADMN',  '',     'Naoki Hirata', 'Magic3.org', 'GPL', 10,      '', true,            true,        false,        false,       false,        false,          false, true, 100, now(),now()),
 ('admin_menu2', '管理用メニュー2', 'ADM2',  '',     'Naoki Hirata', 'Magic3.org', 'GPL', 10,    '', true,            true,        false,        false,       false,        false,          false, true, 100, now(),now()),
-('admin_main',  '管理用画面',      'ADBD',  '',     'Naoki Hirata', 'Magic3.org', 'GPL', 10,     'pagedef=jquery-ui-plus;pagedef_mobile=jquery-ui-plus;', true,            true,        false,        false,       false,        true,          false, true, 0,   now(),now());
+('admin_main',  '管理用画面',      'ADBD',  '',     'Naoki Hirata', 'Magic3.org', 'GPL', 10,     'pagedef=jquery-ui-plus;pagedef_mobile=jquery-ui-plus;menudef=jquery.simpletree;', true,            true,        false,        false,       false,        true,          false, true, 0,   now(),now());
 
 -- ページIDマスター
 INSERT INTO _page_id 
