@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2008 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_std.sql 1324 2008-12-06 11:19:23Z fishbone $
+-- * @version    SVN: $Id: insert_std.sql 1372 2008-12-19 05:06:38Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -192,6 +192,10 @@ INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author,
 DELETE FROM _widgets WHERE wd_id = 'default_login_box';
 INSERT INTO _widgets (wd_id, wd_name, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('default_login_box',         'デフォルトログイン',   '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'デフォルトのログイン用ボックス。', 'md5',        false,           false,       true,         true,        false,        false,               false,true,               100, now(),    now());
+DELETE FROM _widgets WHERE wd_id = 'default_menu';
+INSERT INTO _widgets
+(wd_id,                wd_name,                       wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_add_script_lib_a,                         wd_has_admin, wd_use_instance_def, wd_initialized, wd_install_dt, wd_create_dt) VALUES
+('default_menu', 'デフォルトメニュー',         '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10,                '「default_mainmenu」の次の新型メニューです。サブメニューも管理できます。(現在実装中)', '', '', true,  true,              true,           now(),         now());
 
 -- ウィジェット情報(携帯用)
 DELETE FROM _widgets WHERE wd_id = 'm/sample';
@@ -222,6 +226,10 @@ DELETE FROM _widgets WHERE wd_id = 'm/pc_content';
 INSERT INTO _widgets
 (wd_id,      wd_name,          wd_type, wd_version, wd_params, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_mobile, wd_has_admin, wd_initialized, wd_install_dt, wd_create_dt) VALUES
 ('m/pc_content', 'PC共通コンテンツ', 'content',  '1.0.0',    '',        'Naoki Hirata', 'Magic3.org', 'GPL',      10, 'PC共通コンテンツ表示。',               true,      true,         true,              now(),         now());
+DELETE FROM _widgets WHERE wd_id = 'm/content_search_box';
+INSERT INTO _widgets
+(wd_id,                wd_name,                       wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description,                         wd_mobile, wd_has_admin, wd_initialized, wd_install_dt, wd_create_dt) VALUES
+('m/content_search_box', 'コンテンツ - 検索',         '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'コンテンツを検索するためのボックス。', true,      false,               true,           now(),         now());
 
 -- Wiki設定マスター
 INSERT INTO wiki_config (wg_id,        wg_value,     wg_name,                 wg_index)
@@ -370,6 +378,11 @@ VALUES                 ('what',                   'what',                   '',
 INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_mobile, tm_create_dt) 
 VALUES                 ('m/default',             'm/default',               '',             true,      now());
 
+-- メニューIDマスター
+INSERT INTO _menu_id
+(mn_id,       mn_name,          mn_description, mn_sort_order) VALUES
+('main_menu', 'メインメニュー', '',             0);
+
 -- 基本テーブルの不要なデータを削除
 -- 画面定義
 DELETE FROM _page_def WHERE pd_id = 'index';
